//    ****************************************
//    *                                      *
//    *    BrachyDetectorConstruction.hh     *
//    *                                      *
//    ****************************************


#ifndef BrachyDetectorConstruction_H
#define BrachyDetectorConstruction_H 1

#include "globals.hh"
#include "G4VUserDetectorConstruction.hh"
#include "G4LogicalVolume.hh"


class G4LogicalVolume;
class G4Material;
class G4Tubs;
class G4Box;
class G4Sphere;
class G4Tubs;
class G4VPhysicalVolume;



class G4VPhysicalVolume;
class BrachyDetectorConstruction : public G4VUserDetectorConstruction
{
public:
  BrachyDetectorConstruction();
  ~BrachyDetectorConstruction();


private:
  G4double m_BoxDimX;
  G4double m_BoxDimY;
  G4double m_BoxDimZ;
  G4int NumVoxelX;
  G4int NumVoxelZ;
  G4double dimVoxel;
 

public:
  void PrintDetectorParameters(); 
 
  const   G4double VoxelWidth_X() {return m_BoxDimX/NumVoxelX;};//num voxel
  const   G4double VoxelWidth_Z() {return m_BoxDimZ/NumVoxelZ;};
  const   G4int   GetNumVoxelX(){return NumVoxelX;};
  const   G4int   GetNumVoxelZ(){return NumVoxelZ;};
  const   G4double GetDimX(){return m_BoxDimX;};
       
 
 private:

  G4Box*             ExpHall;    //pointer to the solid World 
  G4LogicalVolume*   ExpHallLog;    //pointer to the logical World
  G4VPhysicalVolume* ExpHallPhys;    //pointer to the physical World


  G4Box*              Phantom;
  G4LogicalVolume*    PhantomLog;
  G4VPhysicalVolume*   PhantomPhys;

   G4Tubs* Capsule ;
  G4LogicalVolume*  CapsuleLog;    //pointer to the logical World
  G4VPhysicalVolume* CapsulePhys;
 
 
   G4Sphere* CapsuleTip;
  G4LogicalVolume* CapsuleTipLog;
  G4VPhysicalVolume*  CapsuleTipPhys;
  
 
  G4Tubs* IridiumCore;
  G4LogicalVolume* IridiumCoreLog;
  G4VPhysicalVolume* IridiumCorePhys;
  
 
  G4Material*              CapsuleMat;
  G4Material*              IridiumMat;
  G4Material*              MaterialBox;

  
 G4Material* DefaultMaterial;

  G4VPhysicalVolume* Construct();
 
private:
         
  void DefineMaterials();
  void ComputeDimVoxel();
   
private:
  G4VPhysicalVolume* ConstructDetector();  

 
};

inline void BrachyDetectorConstruction::ComputeDimVoxel()
{
  dimVoxel=m_BoxDimX/NumVoxelX; 

}

#endif








