

#include <stdlib.h>
#include "g4std/fstream"
#include "BrachyAnalysisManager.hh"

#include "G4ios.hh"

#include "AIDA/IHistogram1D.h"
#include "AIDA/IHistogram2D.h"

#include "AIDA/IPlotterFactory.h"
#include "AIDA/IPlotter.h"

#include "AIDA/IManagedObject.h"
#include "AIDA/IAnalysisFactory.h"
#include "AIDA/IHistogramFactory.h"
#include "AIDA/ITupleFactory.h"
#include "AIDA/ITreeFactory.h"
#include "AIDA/ITree.h"
#include "AIDA/ITuple.h"
#include <AIDA/IManagedObject.h>

BrachyAnalysisManager* BrachyAnalysisManager::instance = 0;

BrachyAnalysisManager::BrachyAnalysisManager() : 
  aFact(0), theTree(0), histFact(0), tupFact(0),plotter(0)
  

{
  aFact=AIDA_createAnalysisFactory();
   //build up  the  factories
 // Creating the tree factory
  ITreeFactory* treeFact= aFact->createTreeFactory();


 
 // Creating a tree mapped to an hbook file.
   theTree = treeFact->create( "brachy3.hbook", false, false, "hbook" );
  G4cout << "Tree store : " <<theTree->storeName() << G4endl;

 
 
  
  //parameters for the TreeFactory
  // bool fileExists = false;
  //bool readOnly   = false;
  //std::string fileName="Brachy3.hbk";
  
// Creating a histogram factory, whose histograms will be handled by the tree


  delete treeFact;
  //HistoFactory and TupleFactory depend on theTree
 
   histFact = aFact->createHistogramFactory( *theTree );
    G4cout<<"Histogram Factory created"<<G4endl;
 
 tupFact  = aFact->createTupleFactory    ( *theTree );
 G4cout<<"Tuple Factory created"<<G4endl;

}



BrachyAnalysisManager::~BrachyAnalysisManager() 
{ 
  delete tupFact;
  tupFact=0;

  delete histFact;
  histFact=0;

  delete theTree;
  histFact=0;

  delete aFact;
  aFact = 0;
  
// delete pf;
// pf=0;
  
  delete plotter;
  plotter=0;

}

BrachyAnalysisManager* BrachyAnalysisManager::getInstance()
{
  if (instance == 0) instance = new BrachyAnalysisManager;
  return instance;
}


void BrachyAnalysisManager::book() 
{

  // histograms and ntuple are managed by theTree
  // h2 e h3 are not necessary  ,useful for:check for non-zero
  //you could do  histFact->create2D("20","Energy, pos",300 ,-150.,150.,300,-15  //0.,150.);
 

  h2 = histFact->create2D("20","Energy, pos",300 ,-150.,150.,300,-150.,150.);
 
  // check for non-zero

  h3 = histFact->create1D("30","Initial Energy", 100,0.,0.5);
  // check for non-zero

  //Ntuple management
  std::string columnNames = "float energy, float x, float z";
  std::string options = "";
  ITuple *tup = tupFact->create("1","brachy",columnNames, options);
  // check for non-zero ...
  if (tup) G4cout<<"The Ntuple is non-zero"<<G4endl;
}
 

//....oooOO0OOooo........oooOO0OOooo........oooOO0OOooo........oooOO0OOooo....


void BrachyAnalysisManager::analyse(G4double xx,G4double zz,G4float en)
{

  ITuple * ntuple = dynamic_cast<ITuple *> ( theTree->find("1") );

 
  ntuple->fill(1, en);// fill ( int column, double value )
  ntuple->fill(2, xx);
  ntuple->fill(3, zz);

  // alternatively(if all the columns are of the same type):
  // std::vector<float> row;
  // row.push_back(en);
  // row.push_back(xx);
  // row.push_back(zz);
  // ntuple->fill(row);

  // write Ntuple-row to file
  // Should be called after fill is called for the columns.
  // Unfilled columns will be filled with the default value for that column.
  ntuple->addRow();

}

void BrachyAnalysisManager::hist(G4double x,G4double z, G4float enn)
{ 
  

  IHistogram2D* h2 = dynamic_cast<IHistogram2D *> ( theTree->find("20") );
  h2->fill(x,z,enn);  
}


void BrachyAnalysisManager::example(G4double Energy)
{ 
  IHistogram1D* h3 = dynamic_cast<IHistogram1D *> ( theTree->find("30") );
  h3->fill(Energy);
}

void BrachyAnalysisManager::plotting()
{ 
 // Creating the plotter factory
   pf= aFact->createPlotterFactory();

// Creating a plotter
   plotter= pf->create();
// Creating two regions
  plotter->clearPage();
  char name[15]="brachy.ps";
  plotter->createRegions(2, 1, 0);
  //sprintf(name,"brachy.ps",1);

  plotter->plot(*h2);
  plotter -> next();
  plotter->plot(*h3);
  plotter ->write(name,"ps");

  plotter->show();

delete pf;
}




void BrachyAnalysisManager::finish() 
{  
  // write all histograms to file
  theTree->commit();

  // close (will again commit)
  theTree->close();

}












