#include "G4RunManager.hh"
#include "G4UImanager.hh"
#include "G4UIterminal.hh"
#include "G4UItcsh.hh"

#include "PhantomDetectorConstruction.hh"
#include "PhantomPhysicsList.hh"
#include "PhantomPrimaryGeneratorAction.hh"
#include "PhantomRunAction.hh"
#include "PhantomEventAction.hh"
#include "PhantomTrackingAction.hh"
#include "PhantomSteppingAction.hh"

#ifdef G4VIS_USE
#include "PhantomVisManager.hh"
#endif

int main(int argc,char** argv)
{
   // RunManager construction
   G4RunManager* runManager = new G4RunManager;

#ifdef G4VIS_USE
   // Visualization manager construction
   G4VisManager* visManager = new PhantomVisManager();
   visManager->Initialize();
#endif

   // mandatory user initialization classes
   runManager->SetUserInitialization(new PhantomDetectorConstruction);
   runManager->SetUserInitialization(new PhantomPhysicsList);

   // initialize Geant4 kernel
   runManager->Initialize();

   // mandatory user action class
   runManager->SetUserAction(new PhantomPrimaryGeneratorAction);

   // optional user action classes
   runManager->SetUserAction(new PhantomRunAction);
   runManager->SetUserAction(new PhantomEventAction);
   runManager->SetUserAction(new PhantomTrackingAction);
   runManager->SetUserAction(new PhantomSteppingAction);

   if(argc>1)
      // execute an argument macro file if exist
   {
      G4UImanager* UImanager = G4UImanager::GetUIpointer();
      G4String command = "/control/execute ";
      G4String fileName = argv[1];
      UImanager->ApplyCommand(command+fileName);
   }
   else
     // start interactive session
   {
      G4UIsession* session = new G4UIterminal(new G4UItcsh);
      session->SessionStart();
      delete session;
   }

#ifdef G4VIS_USE
   delete visManager;
#endif
   
   delete runManager;

   return 0;
}

