
#include  "PhantomHadronPhysics.hh"

PhantomHadronPhysics::PhantomHadronPhysics(const G4String& name) :
   G4VPhysicsConstructor(name)
{
}

PhantomHadronPhysics::~PhantomHadronPhysics()
{
}


#include "G4ParticleDefinition.hh"
#include "G4ParticleTable.hh"

// Nuclei
#include "G4MesonConstructor.hh"
#include "G4BaryonConstructor.hh"
#include "G4ShortLivedConstructor.hh"

void PhantomHadronPhysics::ConstructParticle()
{
   //  Construct all mesons
   G4MesonConstructor pMesonConstructor;
   pMesonConstructor.ConstructParticle();

   //  Construct all barions
   G4BaryonConstructor pBaryonConstructor;
   pBaryonConstructor.ConstructParticle();
  
   return;
}


#include "G4ProcessManager.hh"
#include "G4NeutronHPElasticData.hh"
#include "G4NeutronHPInelasticData.hh"
#include "G4NeutronHPFissionData.hh"
#include "G4NeutronHPCaptureData.hh"


void PhantomHadronPhysics::ConstructProcess()
{
   G4ProcessManager * pManager = 0;
  
   // Proton
   pManager = G4Proton::Proton()->GetProcessManager();
   theProtonElasticModel = new G4LElastic();
   theProtonElasticProcess.RegisterMe(theProtonElasticModel);
   thePreCompoundModel = new G4PreCompoundModel(new G4ExcitationHandler);
   theProtonInelasticProcess.RegisterMe(thePreCompoundModel);

   theProtonIPModel = new G4ProtonIsotopeProduction;
   theProtonInelasticProcess.RegisterIsotopeProductionModel(theProtonIPModel);

   pManager->AddDiscreteProcess(&theProtonElasticProcess);
   pManager->AddDiscreteProcess(&theProtonInelasticProcess);
   pManager->AddProcess(&theProtonIonisation);
   pManager->AddProcess(&theProtonMult);

   
   // Neutron
   pManager = G4Neutron::Neutron()->GetProcessManager();

   G4NeutronHPElasticData * theNeutronElasticData = new G4NeutronHPElasticData;
   G4NeutronHPInelasticData * theNeutronInelasticData = new G4NeutronHPInelasticData;
   G4NeutronHPFissionData * theNeutronFissionData = new G4NeutronHPFissionData;
   G4NeutronHPCaptureData * theNeutronCaptureData = new G4NeutronHPCaptureData;

   theNeutronElasticProcess.GetCrossSectionDataStore()->AddDataSet(theNeutronElasticData);
   theNeutronInelasticProcess.GetCrossSectionDataStore()->AddDataSet(theNeutronInelasticData);
   theNeutronFissionProcess.GetCrossSectionDataStore()->AddDataSet(theNeutronFissionData);
   theNeutronCaptureProcess.GetCrossSectionDataStore()->AddDataSet(theNeutronCaptureData);

   theNeutronElasticModel = new G4NeutronHPElastic;
   theNeutronInelasticModel = new G4NeutronHPInelastic;
   theNeutronFissionModel = new G4NeutronHPFission;
   theNeutronCaptureModel = new G4NeutronHPCapture;

   theNeutronElasticProcess.RegisterMe(theNeutronElasticModel);
   theNeutronInelasticProcess.RegisterMe(theNeutronInelasticModel);
   theNeutronFissionProcess.RegisterMe(theNeutronCaptureModel);
   theNeutronCaptureProcess.RegisterMe(theNeutronFissionModel);

   theNeutronIPModel = new G4NeutronIsotopeProduction;
   theNeutronInelasticProcess.RegisterIsotopeProductionModel(theNeutronIPModel);

   pManager->AddDiscreteProcess(&theNeutronElasticProcess);
   pManager->AddDiscreteProcess(&theNeutronInelasticProcess);
   pManager->AddDiscreteProcess(&theNeutronFissionProcess);
   pManager->AddDiscreteProcess(&theNeutronCaptureProcess);
   

   
   
   return;
}

