
#include "PhantomPrimaryGeneratorAction.hh"
#include "PhantomPrimaryGeneratorActionMessenger.hh"

#include "G4Event.hh"
#include "G4ParticleGun.hh"
#include "G4ParticleTable.hh"
#include "G4ParticleDefinition.hh"
#include "Randomize.hh"



PhantomPrimaryGeneratorAction::PhantomPrimaryGeneratorAction() :
   KineticEnergy(50.0*MeV)
{
   particleGun = new G4ParticleGun(1);

   gunMessenger = new PhantomPrimaryGeneratorActionMessenger(this);

   G4ParticleTable * particleTable = G4ParticleTable::GetParticleTable();
   proton = particleTable->FindParticle("proton");
   neutron = particleTable->FindParticle("neutron");
}

PhantomPrimaryGeneratorAction::~PhantomPrimaryGeneratorAction()
{
   delete particleGun;
   delete gunMessenger;
}

void PhantomPrimaryGeneratorAction::GeneratePrimaries(G4Event* anEvent)
{
   particleGun->SetParticleDefinition(proton);
   particleGun->SetParticleEnergy(KineticEnergy);
   particleGun->SetParticleMomentumDirection(G4ThreeVector(0.0,0.0,1.0));

   G4double z = -20.0*mm;
   G4double phi = 2.0*pi*G4UniformRand();
   G4double r = 7.5*mm * G4UniformRand();
   G4double x = r * cos(phi);
   G4double y = r * sin(phi);

   particleGun->SetParticlePosition(G4ThreeVector(x,y,z));

   particleGun->GeneratePrimaryVertex(anEvent);
   return;
}

