
#ifndef PhantomEyeHit_hh 
#define PhantomEyeHit_hh 1

#include "G4VHit.hh"
#include "G4THitsCollection.hh"
#include "G4Allocator.hh"
#include "G4ThreeVector.hh"
#include "G4LogicalVolume.hh"

class PhantomEyeHit : public G4VHit
{
public:
   PhantomEyeHit() : edep(0.0), localPos(0.0,0.0,0.0), globalPos(0.0,0.0,0.0) {}
   virtual ~PhantomEyeHit() {}
   PhantomEyeHit(const PhantomEyeHit& right);
   const PhantomEyeHit & operator=(const PhantomEyeHit& right);
   G4bool operator==(const PhantomEyeHit& right) const; 

   inline void * operator new(size_t);
   inline void operator delete(void * hit);

   virtual void Draw();
   virtual void Print();

   
   inline void SetEnergyDeposit(const G4double e)
      { edep = e; }
   inline G4double GetEnergyDeposit() const
      { return edep; }
 
   inline void SetLocalPosition(const G4ThreeVector& pos)
      { localPos = pos; }
   inline G4ThreeVector GetLocalPosition()
      { return localPos; }
   
   inline void SetGlobalPosition(const G4ThreeVector& pos)
      { globalPos = pos; }
   inline G4ThreeVector GetGlobalPosition()
      { return globalPos; }

private:
   G4double edep;
   G4ThreeVector localPos;
   G4ThreeVector globalPos;
};


typedef G4THitsCollection<PhantomEyeHit> PhantomEyeHitsCollection;

extern G4Allocator<PhantomEyeHit> PhantomEyeHitAllocator;

inline void * PhantomEyeHit::operator new(size_t)
{
   void * aHit;
   aHit = (void*)PhantomEyeHitAllocator.MallocSingle();
   return aHit;
}

inline void PhantomEyeHit::operator delete(void * hit)
{
   PhantomEyeHitAllocator.FreeSingle((PhantomEyeHit*) hit);
}


#endif
