
#ifndef PhantomHadronPhysics_hh
#define PhantomHadronPhysics_hh 1


#include "globals.hh"

#include "G4VPhysicsConstructor.hh"

#include "G4MultipleScattering.hh"
#include "G4hIonisation.hh"

#include "G4HadronElasticProcess.hh"
#include "G4HadronFissionProcess.hh"
#include "G4HadronCaptureProcess.hh"

#include "G4ProtonInelasticProcess.hh"
#include "G4AntiProtonInelasticProcess.hh"
#include "G4NeutronInelasticProcess.hh"
#include "G4AntiNeutronInelasticProcess.hh"

// Low-energy Models
#include "G4LElastic.hh"   
#include "G4LFission.hh"
#include "G4LCapture.hh"

#include "G4LEProtonInelastic.hh"
#include "G4LENeutronInelastic.hh"

#include "G4LEDeuteronInelastic.hh"
#include "G4LETritonInelastic.hh"
#include "G4LEAlphaInelastic.hh"

// Stopping processes
#include "G4AntiProtonAnnihilationAtRest.hh"
#include "G4AntiNeutronAnnihilationAtRest.hh"


class PhantomHadronPhysics : public G4VPhysicsConstructor
{
public:
   PhantomHadronPhysics(const G4String& name="ion");
   virtual ~PhantomHadronPhysics();

   virtual void ConstructParticle();

   virtual void ConstructProcess();

protected:
   // Elastic Process
   G4HadronElasticProcess theElasticProcess;
   G4LElastic*            theElasticModel;

   // Proton
   G4ProtonInelasticProcess theProtonInelastic;
   G4LEProtonInelastic*     theLEProtonModel;
   G4MultipleScattering     theProtonMult;
   G4hIonisation            theProtonIonisation;
 
   // neutron
   G4NeutronInelasticProcess  theNeutronInelastic;
   G4LENeutronInelastic*      theLENeutronModel;
//   G4HadronFissionProcess     theNeutronFission;
//   G4LFission*                theNeutronFissionModel;
//   G4HadronCaptureProcess     theNeutronCapture;
//   G4LCapture*                theNeutronCaptureModel;

};
#endif

