
#include "PhantomEye.hh"
#include "G4HCofThisEvent.hh"
#include "G4TouchableHistory.hh"
#include "G4Track.hh"
#include "G4Step.hh"
#include "G4SDManager.hh"

PhantomEye::PhantomEye(G4String name) : G4VSensitiveDetector(name)
{
   collectionName.insert("PhantomEyeColl");
   PEID = -1;
}

void PhantomEye::Initialize(G4HCofThisEvent * HCE)
{
   hitsCollection = new PhantomEyeHitsCollection(SensitiveDetectorName,
						 collectionName[0]);

   if (PEID < 0)
   {
      PEID = G4SDManager::GetSDMpointer()->GetCollectionID(hitsCollection);
   }
}

G4bool PhantomEye::ProcessHits(G4Step * aStep, G4TouchableHistory * ROhist)
{
   G4double edep = aStep->GetTotalEnergyDeposit();
   G4StepPoint * PreStepPoint = aStep->GetPreStepPoint();
   G4TouchableHistory * theTouchable =
      (G4TouchableHistory*)(PreStepPoint->GetTouchable());
//   G4VPhysicalVolume * theMotherPhysical = theTouchable->GetVolume(1);
   G4ThreeVector globalPos = PreStepPoint->GetPosition();
   G4ThreeVector localPos = theTouchable->GetHistory()->
      GetTopTransform().TransformPoint(globalPos);
//   G4int copyNo = theMotherPhysical->GetCopyNo();
   PhantomEyeHit * aHit = new PhantomEyeHit();
   aHit->SetEnergyDeposit(edep);
   aHit->SetLocalPosition(localPos);
   aHit->SetGlobalPosition(globalPos);

   hitsCollection->insert(aHit);

   return true;
}

void PhantomEye::EndOfEvent(G4HCofThisEvent * HCE)
{;}
