
#include  "PhantomHadronPhysics.hh"

PhantomHadronPhysics::PhantomHadronPhysics(const G4String& name) :
   G4VPhysicsConstructor(name)
{
}

PhantomHadronPhysics::~PhantomHadronPhysics()
{
}


#include "G4ParticleDefinition.hh"
#include "G4ParticleTable.hh"

// Nuclei
#include "G4MesonConstructor.hh"
#include "G4BaryonConstructor.hh"
#include "G4ShortLivedConstructor.hh"

void PhantomHadronPhysics::ConstructParticle()
{
   //  Construct all mesons
   G4MesonConstructor pMesonConstructor;
   pMesonConstructor.ConstructParticle();

   //  Construct all barions
   G4BaryonConstructor pBaryonConstructor;
   pBaryonConstructor.ConstructParticle();
  
   return;
}


#include "G4ProcessManager.hh"


void PhantomHadronPhysics::ConstructProcess()
{
   G4ProcessManager * pManager = 0;
  
   // Elastic Process
   theElasticModel = new G4LElastic();
   theElasticProcess.RegisterMe(theElasticModel);


   // Proton
   pManager = G4Proton::Proton()->GetProcessManager();
   pManager->AddDiscreteProcess(&theElasticProcess);
   theLEProtonModel = new G4LEProtonInelastic();
   theProtonInelastic.RegisterMe(theLEProtonModel);
   pManager->AddDiscreteProcess(&theProtonInelastic);
   pManager->AddProcess(&theProtonIonisation);
   pManager->AddProcess(&theProtonMult);
//   pManager->AddProcess(&theProtonIonisation, ordInActive,2, 2);
//   pManager->AddProcess(&theProtonMult);
//   pManager->SetProcessOrdering(&theProtonMult, idxAlongStep, 1);
//   pManager->SetProcessOrdering(&theProtonMult, idxPostStep, 1);

   
   // Neutron
   pManager = G4Neutron::Neutron()->GetProcessManager();
   pManager->AddDiscreteProcess(&theElasticProcess);
   theLENeutronModel = new G4LENeutronInelastic();
   theNeutronInelastic.RegisterMe(theLENeutronModel);
   pManager->AddDiscreteProcess(&theNeutronInelastic);
  
//   theNeutronFissionModel = new G4LFission();
//   theNeutronFission.RegisterMe(theNeutronFissionModel);
//   pManager->AddDiscreteProcess(&theNeutronFission);

//   theNeutronCaptureModel = new G4LCapture();
//   theNeutronCapture.RegisterMe(theNeutronCaptureModel);
//   pManager->AddDiscreteProcess(&theNeutronCapture);

   return;
}

