
#include "PhantomIonPhysics.hh"

PhantomIonPhysics::PhantomIonPhysics(const G4String& name) :
   G4VPhysicsConstructor(name)
{
}

PhantomIonPhysics::~PhantomIonPhysics()
{
}

#include "G4ParticleDefinition.hh"
#include "G4ParticleTable.hh"

// Nuclei
#include "G4IonConstructor.hh"

void PhantomIonPhysics::ConstructParticle()
{
   //  Construct light ions
   G4IonConstructor pConstructor;
   pConstructor.ConstructParticle();  
   return;
}


#include "G4ProcessManager.hh"


void PhantomIonPhysics::ConstructProcess()
{
   G4ProcessManager * pManager = 0;
  
   // Elastic Process
   theElasticModel = new G4LElastic();
   theElasticProcess.RegisterMe(theElasticModel);
   
   // Generic Ion
   pManager = G4GenericIon::GenericIon()->GetProcessManager();
   pManager->AddDiscreteProcess(&theElasticProcess);
   pManager->AddProcess(&fIonIonisation);
   pManager->AddProcess(&fIonMultipleScattering);
//   pManager->AddProcess(&fIonIonisation, ordInActive, 2, 2);
//   pManager->AddProcess(&fIonMultipleScattering);
//   pManager->SetProcessOrdering(&fIonMultipleScattering, idxAlongStep,  1);
//   pManager->SetProcessOrdering(&fIonMultipleScattering, idxPostStep,  1);

   // Deuteron 
   pManager = G4Deuteron::Deuteron()->GetProcessManager();
   pManager->AddDiscreteProcess(&theElasticProcess);
   fDeuteronModel = new G4LEDeuteronInelastic();
   fDeuteronProcess.RegisterMe(fDeuteronModel);
   pManager->AddDiscreteProcess(&fDeuteronProcess);
   pManager->AddProcess(&fDeuteronIonisation);
   pManager->AddProcess(&fDeuteronMultipleScattering);
//   pManager->AddProcess(&fDeuteronIonisation, ordInActive, 2, 2);
//   pManager->AddProcess(&fDeuteronMultipleScattering);
//   pManager->SetProcessOrdering(&fDeuteronMultipleScattering, idxAlongStep,  1);
   pManager->SetProcessOrdering(&fDeuteronMultipleScattering, idxPostStep,  1);
 
   // Triton 
   pManager = G4Triton::Triton()->GetProcessManager();
   pManager->AddDiscreteProcess(&theElasticProcess);
  
   fTritonModel = new G4LETritonInelastic();
   fTritonProcess.RegisterMe(fTritonModel);
   pManager->AddDiscreteProcess(&fTritonProcess);
   pManager->AddProcess(&fTritonIonisation);
   pManager->AddProcess(&fTritonMultipleScattering);
//   pManager->AddProcess(&fTritonIonisation, ordInActive, 2, 2);
//   pManager->AddProcess(&fTritonMultipleScattering);
//   pManager->SetProcessOrdering(&fTritonMultipleScattering, idxAlongStep,  1);
//   pManager->SetProcessOrdering(&fTritonMultipleScattering, idxPostStep,  1);
   
   // Alpha 
   pManager = G4Alpha::Alpha()->GetProcessManager();
   pManager->AddDiscreteProcess(&theElasticProcess);
   fAlphaModel = new G4LEAlphaInelastic();
   fAlphaProcess.RegisterMe(fAlphaModel);
   pManager->AddDiscreteProcess(&fAlphaProcess);
   pManager->AddProcess(&fAlphaIonisation);
   pManager->AddProcess(&fAlphaMultipleScattering);
//   pManager->AddProcess(&fAlphaIonisation, ordInActive, 2, 2);
//   pManager->AddProcess(&fAlphaMultipleScattering);
//   pManager->SetProcessOrdering(&fAlphaMultipleScattering, idxAlongStep,  1);
//   pManager->SetProcessOrdering(&fAlphaMultipleScattering, idxPostStep,  1);
   
   // He3
   pManager = G4He3::He3()->GetProcessManager();
   pManager->AddDiscreteProcess(&theElasticProcess);
   pManager->AddProcess(&fHe3Ionisation);
   pManager->AddProcess(&fHe3MultipleScattering);
//   pManager->AddProcess(&fHe3Ionisation, ordInActive, 2, 2);
//   pManager->AddProcess(&fHe3MultipleScattering);
//   pManager->SetProcessOrdering(&fHe3MultipleScattering, idxAlongStep,  1);
//   pManager->SetProcessOrdering(&fHe3MultipleScattering, idxPostStep,  1);
   

   return;
}








