// This code implementation is the intellectual property of
// Vicente R. Lara Camarena.
//
// You cannot copy, distribute or modify the Program (or any work
// based on the Program) without the consent of the author.
//
// --------------------------------------------------------------
// Comments:
//   
// --------------------------------------------------------------

#include "PhantomPhysicsList.hh"

#include "G4ParticleDefinition.hh"
#include "G4ParticleWithCuts.hh"
#include "G4ProcessManager.hh"
#include "G4ProcessVector.hh"
#include "G4ParticleTypes.hh"
#include "G4ParticleTable.hh"

#include "G4Material.hh"
#include "G4MaterialTable.hh"

#include "PhantomGeneralPhysics.hh"
#include "PhantomEMPhysics.hh"
#include "PhantomHadronPhysics.hh"
#include "PhantomIonPhysics.hh"

PhantomPhysicsList::PhantomPhysicsList() :
   G4VModularPhysicsList()
{
   // Default cut value (1.0 mm)
   defaultCutValue = 1.0*mm;
   SetVerboseLevel(1);

   // General Physics
   RegisterPhysics( new PhantomGeneralPhysics("general") );

   // EM Physcis
   RegisterPhysics( new PhantomEMPhysics("standard EM") );

   // Hadron Physics
   RegisterPhysics( new PhantomHadronPhysics("hadron") );

   // Ion Physics
   RegisterPhysics( new PhantomIonPhysics("ion") );

}


PhantomPhysicsList::~PhantomPhysicsList()
{;}

void PhantomPhysicsList::SetCuts()
{
   SetCutsWithDefault();
   DumpCutValuesTable();
}
