

#include "PhantomPrimaryGeneratorActionMessenger.hh"
#include "PhantomPrimaryGeneratorAction.hh"
#include "G4UIcmdWithADoubleAndUnit.hh"

PhantomPrimaryGeneratorActionMessenger::
PhantomPrimaryGeneratorActionMessenger(PhantomPrimaryGeneratorAction* pga) :
   target(pga)
{
   kineticCmd = new G4UIcmdWithADoubleAndUnit("/phantom/SetKineticEnergy", this);
   kineticCmd->SetGuidance("Kinetic energy of proton beam");
   kineticCmd->SetParameterName("K",true);
   kineticCmd->SetRange("K>0. && K<200.");
   kineticCmd->SetDefaultValue(50.0);
   kineticCmd->SetDefaultUnit("MeV");
   kineticCmd->AvailableForStates(Idle);
}


PhantomPrimaryGeneratorActionMessenger::~PhantomPrimaryGeneratorActionMessenger()
{
   delete kineticCmd;
}

void PhantomPrimaryGeneratorActionMessenger::
SetNewValue(G4UIcommand * command, G4String newValue)
{
   if (command == kineticCmd)
      target->SetKineticEnergy(kineticCmd->GetNewDoubleValue(newValue));
   return;
}

G4String PhantomPrimaryGeneratorActionMessenger::
GetCurrentValue(G4UIcommand * command)
{
   G4String cv;
   if (command == kineticCmd)
      cv = kineticCmd->ConvertToString(target->GetKineticEnergy(),"MeV");

   return cv;
}
